import { DlzRegions, OrgOuSecurity } from '../../data-landing-zone-types';
export declare enum ReportType {
    CONTROL_TOWER_CONTROL = "Control Tower Control",
    CONFIG_RULE = "Config Rule",
    SECURITY_HUB_STANDARD = "SecurityHub Standard",
    TAG_POLICY = "Tag Policy",
    SERVICE_CONTROL_POLICY = "Service Control Policy",
    IAM_ACCOUNT_ALIAS = "IAM Account Alias",
    IAM_PASSWORD_POLICY = "IAM Password Policy",
    IAM_PERMISSION_BOUNDARY = "IAM Permission Boundary",
    IAM_POLICY = "IAM Policy",
    IAM_ROLE = "IAM Role",
    IAM_USER = "IAM User",
    IAM_USER_GROUP = "IAM User Group"
}
export interface ReportResource {
    readonly type: ReportType;
    readonly name: string;
    readonly description: string;
    readonly externalLink?: string;
}
/**
 * Behavioral, used with Inheritance
 */
export interface IReportResource {
    readonly reportResource: ReportResource;
}
export interface ReportItem extends ReportResource {
    readonly accountName: string;
    readonly appliedFrom: 'account' | 'ou';
    readonly region: string;
}
export interface PartialAccount {
    readonly name: string;
}
export interface PartialOu {
    readonly ouId: string;
    readonly accounts?: PartialAccount[];
}
export declare class Report {
    static reports: ReportItem[];
    static addReportForAccountRegion(accountName: string, region: string, reportResource: ReportResource): void;
    static addReportForAccountRegions(accountName: string, regions: DlzRegions, reportResource: ReportResource): void;
    static addReportForSecurityOuAccountRegions(securityOu: OrgOuSecurity, regions: DlzRegions, reportResource: ReportResource): void;
    static addReportForOuAccountRegions(partialOu: PartialOu, regions: DlzRegions, reportResource: ReportResource): void;
    static printConsoleReport(): void;
    static saveConsoleReport(): void;
    private static groupByAccountTypeNameAggregatedRegions;
}
