import { DataLandingZoneProps, ForceNoPythonArgumentLifting } from '../data-landing-zone-types';
export declare class Scripts {
    /**
     * Bootstraps all accounts in all regions as defined by the config
     * @param props
     * @param bootstrapRoleName
     */
    boostrapAll(props: DataLandingZoneProps, bootstrapRoleName?: string): Promise<void>;
    /**
     * CDK diff all stacks
     * @param props
     * @param _ Ignore this parameter, it is used to force a consistent interface across TS and Python usage
     */
    diffAll(props: DataLandingZoneProps, _?: ForceNoPythonArgumentLifting): Promise<void>;
    /**
     * CDK diff stacks identified by the id
     * @param props
     * @param id
     */
    diffSelect(props: DataLandingZoneProps, id: string): Promise<void>;
    /**
     * CDK deploy all stacks
     * @param props
     * @param _ Ignore this parameter, it is used to force a consistent interface across TS and Python usage
     */
    deployAll(props: DataLandingZoneProps, _?: ForceNoPythonArgumentLifting): Promise<void>;
    /**
     * CDK deploy stacks identified by the id
     * @param props
     * @param id
     */
    deploySelect(props: DataLandingZoneProps, id: string): Promise<void>;
    /**
     * Sets the Cost Allocation Tags for the organization
     * @param props
     * @param _ Ignore this parameter, it is used to force a consistent interface across TS and Python usage
     */
    configureCostAllocationTags(props: DataLandingZoneProps, _?: ForceNoPythonArgumentLifting): Promise<void>;
    /**
     * Warns about suspended account resources by finding stacks that starts with `dlz-`
     * @param props
     * @param _ Ignore this parameter, it is used to force a consistent interface across TS and Python usage
     */
    warnSuspendedAccountResources(props: DataLandingZoneProps, _?: ForceNoPythonArgumentLifting): Promise<void>;
    /**
     * Runs AWS Nuke on the account.
     *
     * If the account is in the Workloads OU, it will delete all resources but exclude the ControlTower, CDK Bootstrap and DLZ resources.
     * If the account is in the Suspended OU, it will delete all resources but exclude the ControlTower and CDK Bootstrap resources.
     * @param props
     * @param relativeDir Path to the binary
     * @param awsNukeBinary Path to the binary
     * @param accountName Account name as in the props
     * @param dryRun If true (default), it will not delete resources but only list them
     */
    awsNuke(props: DataLandingZoneProps, relativeDir: string, awsNukeBinary: string, accountName: string, dryRun?: boolean): Promise<void>;
}
export default Scripts;
