import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IAMClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IAMClient";
import { EnableOrganizationsRootCredentialsManagementRequest, EnableOrganizationsRootCredentialsManagementResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link EnableOrganizationsRootCredentialsManagementCommand}.
 */
export interface EnableOrganizationsRootCredentialsManagementCommandInput extends EnableOrganizationsRootCredentialsManagementRequest {
}
/**
 * @public
 *
 * The output of {@link EnableOrganizationsRootCredentialsManagementCommand}.
 */
export interface EnableOrganizationsRootCredentialsManagementCommandOutput extends EnableOrganizationsRootCredentialsManagementResponse, __MetadataBearer {
}
declare const EnableOrganizationsRootCredentialsManagementCommand_base: {
    new (input: EnableOrganizationsRootCredentialsManagementCommandInput): import("@smithy/smithy-client").CommandImpl<EnableOrganizationsRootCredentialsManagementCommandInput, EnableOrganizationsRootCredentialsManagementCommandOutput, IAMClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [EnableOrganizationsRootCredentialsManagementCommandInput]): import("@smithy/smithy-client").CommandImpl<EnableOrganizationsRootCredentialsManagementCommandInput, EnableOrganizationsRootCredentialsManagementCommandOutput, IAMClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Enables the management of privileged root user credentials across member accounts in your
 *             organization. When you enable root credentials management for <a href="https://docs.aws.amazon.com/IAM/latest/UserGuide/id_root-user.html#id_root-user-access-management">centralized root access</a>, the management account and the delegated
 *             admininstrator for IAM can manage root user credentials for member accounts in your
 *             organization.</p>
 *          <p>Before you enable centralized root access, you must have an account configured with
 *             the following settings:</p>
 *          <ul>
 *             <li>
 *                <p>You must manage your Amazon Web Services accounts in <a href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_introduction.html">Organizations</a>.</p>
 *             </li>
 *             <li>
 *                <p>Enable trusted access for Identity and Access Management in Organizations. For details, see
 *                         <a href="https://docs.aws.amazon.com/organizations/latest/userguide/services-that-can-integrate-ra.html">IAM and Organizations</a> in the <i>Organizations User
 *                         Guide</i>.</p>
 *             </li>
 *          </ul>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IAMClient, EnableOrganizationsRootCredentialsManagementCommand } from "@aws-sdk/client-iam"; // ES Modules import
 * // const { IAMClient, EnableOrganizationsRootCredentialsManagementCommand } = require("@aws-sdk/client-iam"); // CommonJS import
 * const client = new IAMClient(config);
 * const input = {};
 * const command = new EnableOrganizationsRootCredentialsManagementCommand(input);
 * const response = await client.send(command);
 * // { // EnableOrganizationsRootCredentialsManagementResponse
 * //   OrganizationId: "STRING_VALUE",
 * //   EnabledFeatures: [ // FeaturesListType
 * //     "RootCredentialsManagement" || "RootSessions",
 * //   ],
 * // };
 *
 * ```
 *
 * @param EnableOrganizationsRootCredentialsManagementCommandInput - {@link EnableOrganizationsRootCredentialsManagementCommandInput}
 * @returns {@link EnableOrganizationsRootCredentialsManagementCommandOutput}
 * @see {@link EnableOrganizationsRootCredentialsManagementCommandInput} for command's `input` shape.
 * @see {@link EnableOrganizationsRootCredentialsManagementCommandOutput} for command's `response` shape.
 * @see {@link IAMClientResolvedConfig | config} for IAMClient's `config` shape.
 *
 * @throws {@link AccountNotManagementOrDelegatedAdministratorException} (client fault)
 *  <p>The request was rejected because the account making the request is not the management
 *       account or delegated administrator account for <a href="https://docs.aws.amazon.com/IAM/latest/UserGuide/id_root-user.html#id_root-user-access-management">centralized root
 *         access</a>.</p>
 *
 * @throws {@link CallerIsNotManagementAccountException} (client fault)
 *  <p>The request was rejected because the account making the request is not the management
 *       account for the organization.</p>
 *
 * @throws {@link OrganizationNotFoundException} (client fault)
 *  <p>The request was rejected because no organization is associated with your account.</p>
 *
 * @throws {@link OrganizationNotInAllFeaturesModeException} (client fault)
 *  <p>The request was rejected because your organization does not have All features enabled. For
 *       more information, see <a href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_getting-started_concepts.html#feature-set">Available feature sets</a> in the <i>Organizations User
 *       Guide</i>.</p>
 *
 * @throws {@link ServiceAccessNotEnabledException} (client fault)
 *  <p>The request was rejected because trusted access is not enabled for IAM in Organizations. For details, see IAM and Organizations in the <i>Organizations User Guide</i>.</p>
 *
 * @throws {@link IAMServiceException}
 * <p>Base exception class for all service exceptions from IAM service.</p>
 *
 * @public
 * @example To enable the RootCredentialsManagement feature in your organization
 * ```javascript
 * // The following command enables the management of privileged root user credentials across member accounts in your organization.
 * const input = {};
 * const command = new EnableOrganizationsRootCredentialsManagementCommand(input);
 * const response = await client.send(command);
 * /* response ==
 * {
 *   "EnabledFeatures": [
 *     "RootCredentialsManagement"
 *   ],
 *   "OrganizationId": "o-aa111bb222"
 * }
 * *\/
 * // example id: to-enable-the-rootcredentialsmanagement-feature-in-your-organization-1730908602395
 * ```
 *
 */
export declare class EnableOrganizationsRootCredentialsManagementCommand extends EnableOrganizationsRootCredentialsManagementCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: {};
            output: EnableOrganizationsRootCredentialsManagementResponse;
        };
        sdk: {
            input: EnableOrganizationsRootCredentialsManagementCommandInput;
            output: EnableOrganizationsRootCredentialsManagementCommandOutput;
        };
    };
}
