import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { SSOAdminClientResolvedConfig } from "../SSOAdminClient";
/**
 * @internal
 */
export interface SSOAdminHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface SSOAdminHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<SSOAdminClientResolvedConfig, HandlerExecutionContext, SSOAdminHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultSSOAdminHttpAuthSchemeParametersProvider: (config: SSOAdminClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<SSOAdminHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface SSOAdminHttpAuthSchemeProvider extends HttpAuthSchemeProvider<SSOAdminHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultSSOAdminHttpAuthSchemeProvider: SSOAdminHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: SSOAdminHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: SSOAdminHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
