import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ListApplicationAssignmentsForPrincipalRequest, ListApplicationAssignmentsForPrincipalResponse } from "../models/models_0";
import { ServiceInputTypes, ServiceOutputTypes, SSOAdminClientResolvedConfig } from "../SSOAdminClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListApplicationAssignmentsForPrincipalCommand}.
 */
export interface ListApplicationAssignmentsForPrincipalCommandInput extends ListApplicationAssignmentsForPrincipalRequest {
}
/**
 * @public
 *
 * The output of {@link ListApplicationAssignmentsForPrincipalCommand}.
 */
export interface ListApplicationAssignmentsForPrincipalCommandOutput extends ListApplicationAssignmentsForPrincipalResponse, __MetadataBearer {
}
declare const ListApplicationAssignmentsForPrincipalCommand_base: {
    new (input: ListApplicationAssignmentsForPrincipalCommandInput): import("@smithy/smithy-client").CommandImpl<ListApplicationAssignmentsForPrincipalCommandInput, ListApplicationAssignmentsForPrincipalCommandOutput, SSOAdminClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: ListApplicationAssignmentsForPrincipalCommandInput): import("@smithy/smithy-client").CommandImpl<ListApplicationAssignmentsForPrincipalCommandInput, ListApplicationAssignmentsForPrincipalCommandOutput, SSOAdminClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Lists the applications to which a specified principal is assigned.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { SSOAdminClient, ListApplicationAssignmentsForPrincipalCommand } from "@aws-sdk/client-sso-admin"; // ES Modules import
 * // const { SSOAdminClient, ListApplicationAssignmentsForPrincipalCommand } = require("@aws-sdk/client-sso-admin"); // CommonJS import
 * const client = new SSOAdminClient(config);
 * const input = { // ListApplicationAssignmentsForPrincipalRequest
 *   InstanceArn: "STRING_VALUE", // required
 *   PrincipalId: "STRING_VALUE", // required
 *   PrincipalType: "USER" || "GROUP", // required
 *   Filter: { // ListApplicationAssignmentsFilter
 *     ApplicationArn: "STRING_VALUE",
 *   },
 *   NextToken: "STRING_VALUE",
 *   MaxResults: Number("int"),
 * };
 * const command = new ListApplicationAssignmentsForPrincipalCommand(input);
 * const response = await client.send(command);
 * // { // ListApplicationAssignmentsForPrincipalResponse
 * //   ApplicationAssignments: [ // ApplicationAssignmentListForPrincipal
 * //     { // ApplicationAssignmentForPrincipal
 * //       ApplicationArn: "STRING_VALUE",
 * //       PrincipalId: "STRING_VALUE",
 * //       PrincipalType: "USER" || "GROUP",
 * //     },
 * //   ],
 * //   NextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListApplicationAssignmentsForPrincipalCommandInput - {@link ListApplicationAssignmentsForPrincipalCommandInput}
 * @returns {@link ListApplicationAssignmentsForPrincipalCommandOutput}
 * @see {@link ListApplicationAssignmentsForPrincipalCommandInput} for command's `input` shape.
 * @see {@link ListApplicationAssignmentsForPrincipalCommandOutput} for command's `response` shape.
 * @see {@link SSOAdminClientResolvedConfig | config} for SSOAdminClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient access to perform this action.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The request processing has failed because of an unknown error, exception, or failure
 *             with an internal server.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>Indicates that a requested resource is not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Indicates that the principal has crossed the throttling limits of the API
 *             operations.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The request failed because it contains a syntax error.</p>
 *
 * @throws {@link SSOAdminServiceException}
 * <p>Base exception class for all service exceptions from SSOAdmin service.</p>
 *
 * @public
 */
export declare class ListApplicationAssignmentsForPrincipalCommand extends ListApplicationAssignmentsForPrincipalCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListApplicationAssignmentsForPrincipalRequest;
            output: ListApplicationAssignmentsForPrincipalResponse;
        };
        sdk: {
            input: ListApplicationAssignmentsForPrincipalCommandInput;
            output: ListApplicationAssignmentsForPrincipalCommandOutput;
        };
    };
}
